大话西游之大圣娶亲 (豆瓣)
Description: 大话西游之大圣娶亲电影简介和剧情介绍,大话西游之大圣娶亲影评、图片、预告片、影讯、论坛、在线购票
Keywords: 大话西游之大圣娶亲,西遊記大結局之仙履奇緣,大话西游之大圣娶亲影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.19豆瓣电影Top250

# 大话西游之大圣娶亲 西遊記大結局之仙履奇緣 (1995)

更新描述或海报

导演: 刘镇伟
编剧: 刘镇伟
主演: 周星驰 / 吴孟达 / 朱茵 / 蔡少芬 / 蓝洁瑛 / 莫文蔚 / 罗家英 / 刘镇伟 / 陆树铭 / 李健仁
类型: 喜剧 / 爱情 / 奇幻 / 古装
制片国家/地区: 中国香港 / 中国大陆
语言: 粤语 / 汉语普通话
上映日期: 2014-10-24(中国大陆) / 2017-04-13(中国大陆重映) / 1995-02-04(中国香港)
片长: 95分钟 / 110分钟(重映版)
又名: 西游记完结篇仙履奇缘 / 齐天大圣西游记 / 大话东游之二 / A Chinese Odyssey Part Two - Cinderella / 大话西游之大圣娶妻
IMDb: tt0114996
豆瓣评分
引用
9.2
1461337人评价
5星
67.0%
4星
26.5%
3星
5.8%
2星
0.5%
1星
0.3%
好友评分
你关注的人看过这部作品的平均分
8.0
4人评价
好于 99% 喜剧片
好于 99% 爱情片
我看过这部电影 2020-07-12 修改
我的评价:
推荐

## 大话西游之大圣娶亲的剧情简介 · · · · · ·

至尊宝（周星驰 饰）被月光宝盒带回到五百年前，遇见紫霞仙子（朱茵 饰），被对方打上烙印成为对方的人，并发觉自己已变成孙悟空。
紫霞与青霞（朱茵 饰）本是如来佛祖座前日月神灯的灯芯（白天是紫霞，晚上是青霞），二人虽然同一肉身却仇恨颇深，因此紫霞立下誓言，谁能拔出她手中的紫青宝剑，谁就是她的意中人。紫青宝剑被至尊宝于不经意间拔出，紫霞决定以身相许，却遭一心记挂白晶晶（莫文蔚 饰）的至尊宝拒绝。后牛魔王救下迷失在沙漠中的紫霞，并逼紫霞与他成婚，关键时刻，至尊宝现身。 ©豆瓣

## 大话西游之大圣娶亲的演职员 · · · · · · ( 全部 35 )

- 刘镇伟 导演
- 周星驰 饰 至尊宝/孙悟空
- 吴孟达 饰 二当家 / 猪八戒 / 状元
- 朱茵 饰 紫霞仙子 / 盘丝大仙 / 青霞仙子
- 蔡少芬 饰 铁扇公主
- 蓝洁瑛 饰 春三十娘 / 状元娘子

## 大话西游之大圣娶亲的视频和图片 · · · · · · ( 预告片7 | 视频评论1 · 添加 | 图片1475 · 添加 )

## 大话西游之大圣娶亲的获奖情况 · · · · · · ( 全部 )

- 第15届香港电影金像奖
- 最佳编剧(提名)
- 刘镇伟

- 第15届香港电影金像奖
- 最佳男主角(提名)
- 周星驰

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  泰坦尼克号

  大话西游之月光宝盒

  倩女幽魂

  重庆森林

  甜蜜蜜

  剪刀手爱德华

  花样年华

  怦然心动

  天使爱美丽

我要写短评

## 大话西游之大圣娶亲的短评 · · · · · · ( 全部 247465 条 )

热门 / 最新 / 好友

### 2498 有用 仲楚 看过 2018-01-30 23:44:02

紫霞仙子眨眼的一瞬惊艳，无忧无虑的至尊宝。 至尊宝面对现实的两条路: 不成大圣，我无法救你。成了大圣，我无法爱你。

### 1416 有用 woodYA!!en 看过 2011-03-17 23:03:33

鲜花虽会凋谢，但会再开。一生所爱，隐约在白云外。苦海翻起爱恨，在世间难逃避命运。相亲竟不可接近，或我应该相信是命运。

### 13950 有用 罗弘霉素 看过 2010-07-26 18:41:26

一遍烂，两遍笑，三遍哭

### 6717 有用 Lan~die 看过 2006-10-07 10:48:36

经历过和正在经历着悟空式的命运和紫霞式的爱情，才发现生命的本质是以最低的姿态出现的。英雄？你为什么不问问做英雄的代价？ “想不到经过这五百年，我要找的并不是她，而是你。”人生际遇真是难以言喻。

### 8535 有用 Mona Lishark 看过 2008-01-01 19:41:02

有人跟我比赛背台词么

> 更多短评 247465条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 黑烟的圈 看过 2020-08-13 11:36:14

始于少女撑船寻爱，止于中男事业为重。

### 2 有用 LLudeer 看过 2013-10-09 14:12:58

原来爱的人在你心里留下的东西是一滴泪。ps:朱茵好漂亮~

我要写影评

## 大话西游之大圣娶亲的影评 · · · · · · ( 全部 4665 条 )

热门 / 最新 / 好友
苗汉子 2011-12-04 19:53:35

## 你理解大话西游片尾那句“他好像一条狗”吗？如果不能理解，那就是没看懂。

你在看大话西游的时候，如果笑得腹背抽筋，龇牙咧嘴，那么你很有幽默感。如果你看完了大话西游，你还笑得满地打滚，那么你其实什么都没看懂。如果你看完了大话，你忽然发现脸上不知什么时候已经有泪水，你总算看懂了大话的第一层了。如果你看完大话，笑也笑过了，泪也流过了，... (展开)
18627 1055 1263回应 收起
我对你的无语简直能沉默整个宇宙 2008-05-21 16:07:07

## 我们所不能抗拒的只有爱与死

199X年。小学。东北某矿区职工电影院。 　　我跟很多小孩子挤在黑暗里看妖魔鬼怪。我们只是冲着孙悟空猪八戒来的。我不明白里面怎么会冒出来那么多女的跟孙悟空扯上瓜葛，原来都是妖精们或者女儿国的女儿们喜欢唐僧才对呀。电影里的妖怪也好可怕，总是在黑漆漆的夜里出现，... (展开)
5351 251 411回应 收起
邓歌 2009-06-20 21:30:35

## 《大话西游》里面爱情伦理观

《大话西游》是我最喜欢的一部有关于爱情的电影，完全符合我对爱情伦理的最本源的想法。符合我爱情伦理观的电影有两部，另一部是《屋顶上的轻骑兵》，那个我以前在豆瓣上曾经写过，更侧重于精神分析。其实《大话西游》和《屋顶上的轻骑兵》有一些相似之处，但《大话西游》更接... (展开)
4280 141 345回应 收起
喜宴 2010-03-22 17:30:36

## 来一篇转的全剧本吧

这篇影评可能有剧透

大话西游 （一） 观音：孙悟空，你这个畜牲，你本来答应如来佛祖护送你师傅唐三藏去取西经的，你居然跟牛魔王串通要吃你师傅，你知不知道你犯了弥天大罪？ 孙悟空：少罗嗦！你追了我三天三夜，因为你是女人我才不杀你，不要以为我怕了你！ 唐僧：悟空，你怎么可以这样跟观音... (展开)
910 23 44回应 收起
谢小麦 2008-07-29 17:31:01

## 不过是只受了诅咒的猴子。

周六的时候参加米兜组织的活动，到好北边的中国电影博物馆，看很久之前已经看过很多遍的《大话西游》。虽然路程远了一些，电影票还是好便宜；又赶上蜡像馆开幕，也算是不虚此行。 十多年前第一次看的时候，是电视台放的，中间看起，基本上没看明白。后来上了大学，赶上... (展开)
638 45 117回应 收起
鱼·无 2008-02-19 01:48:35

## 玩什么别玩剑

一个女人。 一个身材玲珑，风情不羁的女人。 一个天上有地下无，机敏跳脱，额头光洁而红唇饱满的女人。 她衣袂翩翩，青丝飘扬，贝齿如编。手腕上一串银铃，牵起天地间的靡靡之音，纵是天兵神将，都要元魂颠倒。 但她带着一把剑。 剑，本来也没什么，居家旅行防身绑架寻仇……之... (展开)
494 72 126回应 收起
离净语 2014-03-30 03:53:39

## 男性的焦虑

［两段台词］ 刘镇伟全片对王家卫进行戏仿，其中男女主角的两段台词，成为了观众反复背诵的名句： 男主角：曾经有一份真诚的爱情摆在我的面前，但是我没有珍惜，等到了失去的时候才后悔莫及，尘世间最痛苦的事莫过于此。如果可以给我一个机会再来一次的话，我会跟那个女孩子说... (展开)
446 25 58回应 收起
shawn 2007-10-13 16:21:12

## 重温《大话西游》 (转)

这篇影评可能有剧透

昨晚夜静，重温《大话西游》 ——大笑，流泪，然后沉默。 　　我面对的是一部痛彻心肺的喜剧。 　　寓言篇故事已然存在，已然不可避免。 　　世界是巨大的枷锁，你不得不重复自己或是别人的生活。 　　记得长辈说过：年轻是一种罪过。他们说我们不成熟。 　　真切... (展开)
471 30 99回应 收起
法爷就是Faye 2010-07-19 10:34:41

## 让你卑微到尘埃里的不过那么一个人

以前我一直不懂为什么别人看大话西游的时候鼻涕一把眼泪一把。 在我自己看到鼻涕一把眼泪一把的时候，我又知道了，这不过又是一个时间和经历教会你的事情。 最好的喜剧，究竟是什么样子？放大所有的悲伤，夸张所有的情感，然后变成一出闹剧的故事是否就能是最好的喜剧？ 我看... (展开)
367 18 72回应 收起

> 更多影评 4665篇

添加新讨论

## 讨论区 · · · · · ·

这么烂的电影，怎么评分这么高？ | 来自LET IT GO | 55 回应 | 2022-11-23 22:14:51
既然还有人洗 | 来自瑟瑟发抖 | 3 回应 | 2022-11-23 05:11:21
粗制滥造，不过是一文不值的辣鸡罢了! | 来自格兰洛伊斯 | 20 回应 | 2022-11-22 20:13:30
寂寞的时候还有人可以当个慰安妇 | 来自TGTW538 | 20 回应 | 2022-11-22 08:01:43
抄袭 | 来自时间机器 | 6 回应 | 2022-11-19 09:17:23

> 去这部影片的讨论区（全部1035条）

## 关于《大话西游之大圣娶亲》的问题 · · · · · · ( 全部57个 )

- 最后那个夕阳武士，所以就理所当然地抛弃了他的妻子，而跟“紫霞仙子”在一起了吗？ 7人回答
- 紫霞为什么不能陪孙悟空去取经？ 33人回答

> 全部57个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 文艺女王必修课「华语篇」 (不良生)
- 【内牛满面】 (影志)
- 80末出生的人是这样成长的 (沉歌)

## 谁在看这部电影 · · · · · ·

- 刘有志
  1分钟前 看过
- 千层度
  1分钟前 看过
- 峰峰
  2分钟前 看过

2732479人看过 / 203758人想看

订阅大话西游之大圣娶亲的评论:
feed: rss 2.0